@@ -2,4 +2,4 @@ from django.apps import AppConfig
 
 
 class Djangosaml2SpidConfig(AppConfig):
-    name = 'djangosaml2_spid'
+    name = "djangosaml2_spid"
